@@ -4,31 +4,30 @@
 # Copyright (c) 2020, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
-import distutils
+from distutils import dir_util
 import os
 import shutil
-from collections import Iterable
+from collections.abc import Iterable
 
 import numpy as np
 import pandas as pd
 from ads.common import logger, utils
 from ads.common.model_export_util import (
-    ONNXTransformer,
     Progress_Steps_W_Fn,
     Progress_Steps_Wo_Fn,
     prepare_generic_model,
     serialize_model,
 )
+from ads.model.transformer.onnx_transformer import ONNXTransformer
 from ads.common.decorator.runtime_dependency import (
     runtime_dependency,
     OptionalDependency,
 )
+from ads.common.decorator.deprecate import deprecated
 from ads.common.utils import is_notebook
 from ads.dataset.pipeline import TransformerPipeline
-from distutils import dir_util
 from sklearn.pipeline import Pipeline
 
-
 Unsupported_Model_Types = []
 NoTransformModels = ["torch", "tensorflow", "keras", "automl"]
 
@@ -171,14 +170,18 @@ class ADSModel(object):
         """
         self.name = name
 
+    @deprecated(
+        "2.6.6",
+        details="Use framework specific Model utility class for saving and deploying model. Check https://accelerated-data-science.readthedocs.io/en/latest/user_guide/model_registration/quick_start.html",
+    )
     def predict(self, X):
         """
         Runs the models predict function on some data
 
         Parameters
         ----------
-        X: MLData
-            A MLData object which holds the examples to be predicted on.
+        X: ADSData
+            A ADSData object which holds the examples to be predicted on.
 
         Returns
         -------
@@ -202,8 +205,8 @@ class ADSModel(object):
 
         Parameters
         ----------
-        X: MLData
-            A MLData object which holds the examples to be predicted on.
+        X: ADSData
+            A ADSData object which holds the examples to be predicted on.
 
         Returns
         -------
@@ -218,16 +221,20 @@ class ADSModel(object):
         else:
             return self.est.predict_proba(X)
 
+    @deprecated(
+        "2.6.6",
+        details="Use framework specific Model utility class for saving and deploying model. Check https://accelerated-data-science.readthedocs.io/en/latest/user_guide/model_registration/quick_start.html",
+    )
     def score(self, X, y_true, score_fn=None):
         """
         Scores a model according to a custom score function
 
         Parameters
         ----------
-        X: MLData
-            A MLData object which holds the examples to be predicted on.
-        y_true: MLData
-            A MLData object which holds ground truth labels for the examples which are being predicted on.
+        X: ADSData
+            A ADSData object which holds the examples to be predicted on.
+        y_true: ADSData
+            A ADSData object which holds ground truth labels for the examples which are being predicted on.
         score_fn: Scorer (callable)
             A callable object that returns a score, usually created with sklearn.metrics.make_scorer().
 
@@ -250,6 +257,10 @@ class ADSModel(object):
             else:
                 return self.est.score(X, y_true)
 
+    @deprecated(
+        "2.6.6",
+        details="Use framework specific Model utility class for saving and deploying model. Check https://accelerated-data-science.readthedocs.io/en/latest/user_guide/model_registration/quick_start.html",
+    )
     def summary(self):
         """
         A summary of the ADSModel
@@ -274,14 +285,18 @@ class ADSModel(object):
     def __getattr__(self, item):
         return getattr(self.est, item)
 
+    @deprecated(
+        "2.6.6",
+        details="Use framework specific Model utility class for saving and deploying model. Check https://accelerated-data-science.readthedocs.io/en/latest/user_guide/model_registration/quick_start.html",
+    )
     def transform(self, X):
         """
-        Process some MLData through the selected ADSModel transformers
+        Process some ADSData through the selected ADSModel transformers
 
         Parameters
         ----------
-        X: MLData
-            A MLData object which holds the examples to be transformed.
+        X: ADSData
+            A ADSData object which holds the examples to be transformed.
         """
 
         if hasattr(X, "copy"):
@@ -310,6 +325,10 @@ class ADSModel(object):
         """
         return hasattr(self, "classes_") and self.classes_ is not None
 
+    @deprecated(
+        "2.6.6",
+        details="Use framework specific Model utility class for saving and deploying model. Check https://accelerated-data-science.readthedocs.io/en/latest/user_guide/model_registration/quick_start.html",
+    )
     def feature_names(self, X=None):
         model_type = self._underlying_model
         if model_type == "sklearn":
@@ -367,6 +386,10 @@ class ADSModel(object):
     def __setstate__(self, state):
         self.__dict__ = state
 
+    @deprecated(
+        "2.6.6",
+        details="Use framework specific Model utility class for saving and deploying model. Check https://accelerated-data-science.readthedocs.io/en/latest/user_guide/model_registration/quick_start.html",
+    )
     def prepare(
         self,
         target_dir=None,
@@ -472,7 +495,7 @@ class ADSModel(object):
                 ),
                 os.path.join(target_dir, ".model-ignore"),
             )
-            distutils.dir_util._path_created = {}
+            dir_util._path_created = {}
 
             progress.update("Serializing model")
             # Transform the data to be onnx-ready
