@@ -3,12 +3,14 @@
 
 # Copyright (c) 2021, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
-from typing import Any, Optional, Union
-import oci.data_science.models as data_science_models
+from typing import Any, Dict, Optional, Union
 
-from ads.common.oci_datascience import OCIDataScienceMixin
+import oci.data_science.models as data_science_models
+from ads.common import utils
 from ads.common.auth import default_signer
 from ads.common.oci_client import OCIClientFactory
+from ads.common.oci_datascience import OCIDataScienceMixin
+
 from .common.utils import OCIClientManager
 
 
@@ -49,6 +51,8 @@ class ModelDeploymentProperties(
         "access_log_id",
         "predict_log_group_id",
         "predict_log_id",
+        "memory_in_gbs",
+        "ocpus",
     ]
 
     def __init__(
@@ -59,7 +63,7 @@ class ModelDeploymentProperties(
             data_science_models.ModelDeployment,
             data_science_models.CreateModelDeploymentDetails,
             data_science_models.UpdateModelDeploymentDetails,
-            dict,
+            Dict,
         ] = None,
         config: dict = None,
         **kwargs,
@@ -68,23 +72,23 @@ class ModelDeploymentProperties(
 
         Parameters
         ----------
-        model_id : str
+        model_id: (str, optiona). Defaults to None.
             Model Artifact OCID. The model_id must be specified either
             explicitly or as an attribute of the OCI object.
-        model_uri : str
-            uri to model files, can be local or in cloud storage.
-        oci_model_deployment: ModelDeployment or CreateModelDeploymentDetails or UpdateModelDeploymentDetails or dict
-            An OCI model or dict containing model deployment details.
-            The OCI model can be an instance of either ModelDeployment,
-            CreateModelDeploymentDetails or UpdateModelConfigurationDetails.
-        config : dict
+        model_uri: (str, optiona). Defaults to None.
+            Uri to model files, can be local or in cloud storage.
+        oci_model_deployment: (Union[ModelDeployment, CreateModelDeploymentDetails, UpdateModelDeploymentDetails, Dict], optional). Defaults to None.
+            An OCI model or Dict containing model deployment details.
+            The OCI model can be an instance of either `ModelDeployment`,
+            `CreateModelDeploymentDetails` or `UpdateModelConfigurationDetails`.
+        config : (Dict, optional). Defaults to None.
             ADS auth dictionary for OCI authentication.
             This can be generated by calling ads.common.auth.api_keys() or
             ads.common.auth.resource_principal().
             If this is None, ads.common.default_signer(client_kwargs) will be used.
-        kwargs :
+        kwargs:
             Users can also initialize the object by using keyword arguments.
-            The following keyword arguments are supported by OCI models:
+            The following keyword arguments are supported by `oci.data_science.models.data_science_models.ModelDeployment`:
 
             - `display_name`,
             - `description`,
@@ -95,6 +99,9 @@ class ModelDeploymentProperties(
             - `freeform_tags`,
             - `defined_tags`.
 
+            If display_name is not specified, a randomly generated easy to remember name will be generated,
+            like 'strange-spider-2022-08-17-23:55.02'.
+
             ModelDeploymentProperties also supports the following additional
             keyward arguments:
 
@@ -104,7 +111,9 @@ class ModelDeploymentProperties(
             - `access_log_group_id`,
             - `access_log_id`,
             - `predict_log_group_id`,
-            - `predict_log_id`.
+            - `predict_log_id`,
+            - `memory_in_gbs`,
+            - `ocpus`.
 
             These additional arguments will be saved into appropriate properties
             in the OCI model.
@@ -166,6 +175,10 @@ class ModelDeploymentProperties(
         # Convert all keys to lower case
         kwargs = {str(k).lower(): v for k, v in kwargs.items()}
 
+        # Set default display_name if not specified - randomly generated easy to remember name generated
+        if "display_name" not in kwargs or kwargs["display_name"] is None:
+            kwargs["display_name"] = utils.get_random_name_for_resource()
+
         # Set ModelDeployment properties
         for key, val in kwargs.items():
             if key in self.swagger_types.keys():
@@ -173,7 +186,13 @@ class ModelDeploymentProperties(
 
         # Config instance
         instance_config = {}
-        for key in ["instance_shape", "instance_count", "bandwidth_mbps"]:
+        for key in [
+            "instance_shape",
+            "instance_count",
+            "bandwidth_mbps",
+            "memory_in_gbs",
+            "ocpus",
+        ]:
             if key in kwargs:
                 instance_config[key] = kwargs[key]
         if instance_config:
@@ -205,9 +224,11 @@ class ModelDeploymentProperties(
             dictionary containing instance configuration about the deployment.
             The following keys are supported:
 
-            - instance_shape,
-            - instance_count,
-            - bandwidth_mbps.
+            - instance_shape: str,
+            - instance_count: int,
+            - bandwidth_mbps: int,
+            - memory_in_gbs: float,
+            - ocpus: float
 
             The instance_shape and instance_count are required when creating a new deployment.
             They are optional when updating an existing deployment.
@@ -234,6 +255,18 @@ class ModelDeploymentProperties(
         instance_configuration_object = data_science_models.InstanceConfiguration()
         if "instance_shape" in config:
             instance_configuration_object.instance_shape_name = config["instance_shape"]
+
+        if config.get("memory_in_gbs") or config.get("ocpus"):
+            instance_shape_config_details = (
+                data_science_models.ModelDeploymentInstanceShapeConfigDetails(
+                    memory_in_gbs=config.pop("memory_in_gbs", None),
+                    ocpus=config.pop("ocpus", None),
+                )
+            )
+            instance_configuration_object.model_deployment_instance_shape_config_details = (
+                instance_shape_config_details
+            )
+
         model_configuration_details_object.instance_configuration = (
             instance_configuration_object
         )
