@@ -5,7 +5,7 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import abc
-from ads.common.model_metadata import MetadataTaxonomyKeys
+from ads.model.model_metadata import MetadataTaxonomyKeys
 from typing import Dict
 
 
